# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: graphsignal/profilers/tensorflow_proto/diagnostics.proto
"""Generated protocol buffer code."""
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import message as _message
from google.protobuf import reflection as _reflection
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n8graphsignal/profilers/tensorflow_proto/diagnostics.proto\x12\x13tensorflow.profiler\"=\n\x0b\x44iagnostics\x12\x0c\n\x04info\x18\x01 \x03(\t\x12\x10\n\x08warnings\x18\x02 \x03(\t\x12\x0e\n\x06\x65rrors\x18\x03 \x03(\tb\x06proto3')



_DIAGNOSTICS = DESCRIPTOR.message_types_by_name['Diagnostics']
Diagnostics = _reflection.GeneratedProtocolMessageType('Diagnostics', (_message.Message,), {
  'DESCRIPTOR' : _DIAGNOSTICS,
  '__module__' : 'graphsignal.profilers.tensorflow_proto.diagnostics_pb2'
  # @@protoc_insertion_point(class_scope:tensorflow.profiler.Diagnostics)
  })
_sym_db.RegisterMessage(Diagnostics)

if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _DIAGNOSTICS._serialized_start=81
  _DIAGNOSTICS._serialized_end=142
# @@protoc_insertion_point(module_scope)
